const API_BASE_URL = 'https://digiticket.dmlabs.in/api';

export class ApiService {
  private async makeRequest(endpoint: string, options: RequestInit = {}) {
    const url = `${API_BASE_URL}${endpoint}`;
    const config: RequestInit = {
      headers: {
        'Content-Type': 'application/json',
        ...options.headers,
      },
      ...options,
    };

    try {
      const response = await fetch(url, config);
      
      if (!response.ok) {
        const errorData = await response.json().catch(() => ({}));
        throw new Error(errorData.error || `HTTP error! status: ${response.status}`);
      }
      
      return await response.json();
    } catch (error) {
      console.error(`API request failed for ${endpoint}:`, error);
      throw error;
    }
  }

  async submitTicket(ticketData: {
    requester: string;
    email: string;
    content: string;
  }) {
    return this.makeRequest('/submit-ticket', {
      method: 'POST',
      body: JSON.stringify(ticketData),
    });
  }

  async getTickets() {
    return this.makeRequest('/tickets');
  }

  async sendChatMessage(messages: Array<{ role: string; content: string }>) {
    const response = await this.makeRequest('/chat', {
      method: 'POST',
      body: JSON.stringify({ messages }),
    });
    return response.response;
  }

  async createTicketFromChat(data: {
    requester: string;
    email: string;
    conversation: string;
  }) {
    return this.makeRequest('/chat/create-ticket', {
      method: 'POST',
      body: JSON.stringify(data),
    });
  }

  async getQuickResponse(issueType: string) {
    return this.makeRequest('/chat/quick-response', {
      method: 'POST',
      body: JSON.stringify({ issue_type: issueType }),
    });
  }
}

export const apiService = new ApiService();